@@ -173,6 +173,11 @@ use strict;
     PVIP_NODE_GCD
     PVIP_NODE_KEEP
     PVIP_NODE_UNDO
+    PVIP_NODE_NOW
+    PVIP_NODE_UNTIL
+    PVIP_NODE_TIME
+    PVIP_NODE_AUGMENT
+    PVIP_NODE_IS_COPY
     PVIP_CATEGORY_UNKNOWN
     PVIP_CATEGORY_STRING
     PVIP_CATEGORY_INT
