@@ -171,6 +171,11 @@ static void setup_pvip_const() {
     PConst(PVIP_NODE_GCD);
     PConst(PVIP_NODE_KEEP);
     PConst(PVIP_NODE_UNDO);
+    PConst(PVIP_NODE_NOW);
+    PConst(PVIP_NODE_UNTIL);
+    PConst(PVIP_NODE_TIME);
+    PConst(PVIP_NODE_AUGMENT);
+    PConst(PVIP_NODE_IS_COPY);
     PConst(PVIP_CATEGORY_UNKNOWN);
     PConst(PVIP_CATEGORY_STRING);
     PConst(PVIP_CATEGORY_INT);
